@@ -16,17 +16,19 @@
 #
 
 from collections import OrderedDict
+from distutils import util
 import os
 import re
-from typing import Callable, Dict, Sequence, Tuple, Type, Union
+from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core import client_options as client_options_lib  # type: ignore
 from google.api_core import exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
+from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
@@ -40,7 +42,7 @@ from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
 from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
 from google.rpc import status_pb2 as status  # type: ignore
 
-from .transports.base import CloudSchedulerTransport
+from .transports.base import CloudSchedulerTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import CloudSchedulerGrpcTransport
 from .transports.grpc_asyncio import CloudSchedulerGrpcAsyncIOTransport
 
@@ -117,6 +119,22 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         DEFAULT_ENDPOINT
     )
 
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            CloudSchedulerClient: The constructed client.
+        """
+        credentials = service_account.Credentials.from_service_account_info(info)
+        kwargs["credentials"] = credentials
+        return cls(*args, **kwargs)
+
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
@@ -129,7 +147,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            CloudSchedulerClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_file(filename)
         kwargs["credentials"] = credentials
@@ -137,6 +155,15 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> CloudSchedulerTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            CloudSchedulerTransport: The transport used by the client instance.
+        """
+        return self._transport
+
     @staticmethod
     def job_path(project: str, location: str, job: str,) -> str:
         """Return a fully-qualified job string."""
@@ -153,12 +180,83 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         )
         return m.groupdict() if m else {}
 
+    @staticmethod
+    def topic_path(project: str, topic: str,) -> str:
+        """Return a fully-qualified topic string."""
+        return "projects/{project}/topics/{topic}".format(project=project, topic=topic,)
+
+    @staticmethod
+    def parse_topic_path(path: str) -> Dict[str, str]:
+        """Parse a topic path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)/topics/(?P<topic>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_billing_account_path(billing_account: str,) -> str:
+        """Return a fully-qualified billing_account string."""
+        return "billingAccounts/{billing_account}".format(
+            billing_account=billing_account,
+        )
+
+    @staticmethod
+    def parse_common_billing_account_path(path: str) -> Dict[str, str]:
+        """Parse a billing_account path into its component segments."""
+        m = re.match(r"^billingAccounts/(?P<billing_account>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_folder_path(folder: str,) -> str:
+        """Return a fully-qualified folder string."""
+        return "folders/{folder}".format(folder=folder,)
+
+    @staticmethod
+    def parse_common_folder_path(path: str) -> Dict[str, str]:
+        """Parse a folder path into its component segments."""
+        m = re.match(r"^folders/(?P<folder>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_organization_path(organization: str,) -> str:
+        """Return a fully-qualified organization string."""
+        return "organizations/{organization}".format(organization=organization,)
+
+    @staticmethod
+    def parse_common_organization_path(path: str) -> Dict[str, str]:
+        """Parse a organization path into its component segments."""
+        m = re.match(r"^organizations/(?P<organization>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_project_path(project: str,) -> str:
+        """Return a fully-qualified project string."""
+        return "projects/{project}".format(project=project,)
+
+    @staticmethod
+    def parse_common_project_path(path: str) -> Dict[str, str]:
+        """Parse a project path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def common_location_path(project: str, location: str,) -> str:
+        """Return a fully-qualified location string."""
+        return "projects/{project}/locations/{location}".format(
+            project=project, location=location,
+        )
+
+    @staticmethod
+    def parse_common_location_path(path: str) -> Dict[str, str]:
+        """Parse a location path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
+        return m.groupdict() if m else {}
+
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
-        transport: Union[str, CloudSchedulerTransport] = None,
-        client_options: ClientOptions = None,
+        credentials: Optional[credentials.Credentials] = None,
+        transport: Union[str, CloudSchedulerTransport, None] = None,
+        client_options: Optional[client_options_lib.ClientOptions] = None,
+        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiate the cloud scheduler client.
 
@@ -168,51 +266,73 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-            transport (Union[str, ~.CloudSchedulerTransport]): The
+            transport (Union[str, CloudSchedulerTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (ClientOptions): Custom options for the client. It
-                won't take effect if a ``transport`` instance is provided.
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
-                default endpoint provided by the client. GOOGLE_API_USE_MTLS
+                default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                 environment variable can also be used to override the endpoint:
                 "always" (always use the default mTLS endpoint), "never" (always
-                use the default regular endpoint, this is the default value for
-                the environment variable) and "auto" (auto switch to the default
-                mTLS endpoint if client SSL credentials is present). However,
-                the ``api_endpoint`` property takes precedence if provided.
-                (2) The ``client_cert_source`` property is used to provide client
-                SSL credentials for mutual TLS transport. If not provided, the
-                default SSL credentials will be used if present.
+                use the default regular endpoint) and "auto" (auto switch to the
+                default mTLS endpoint if client certificate is present, this is
+                the default value). However, the ``api_endpoint`` property takes
+                precedence if provided.
+                (2) If GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
+                is "true", then the ``client_cert_source`` property can be used
+                to provide client certificate for mutual TLS transport. If
+                not provided, the default SSL client certificate will be used if
+                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
+                set, no client certificate will be used.
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
+                your own client library.
 
         Raises:
             google.auth.exceptions.MutualTLSChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
         if isinstance(client_options, dict):
-            client_options = ClientOptions.from_dict(client_options)
+            client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
-            client_options = ClientOptions.ClientOptions()
+            client_options = client_options_lib.ClientOptions()
 
-        if client_options.api_endpoint is None:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS", "never")
-            if use_mtls_env == "never":
-                client_options.api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                client_options.api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                has_client_cert_source = (
-                    client_options.client_cert_source is not None
-                    or mtls.has_default_client_cert_source()
+        # Create SSL credentials for mutual TLS if needed.
+        use_client_cert = bool(
+            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        )
+
+        client_cert_source_func = None
+        is_mtls = False
+        if use_client_cert:
+            if client_options.client_cert_source:
+                is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
+            else:
+                is_mtls = mtls.has_default_client_cert_source()
+                client_cert_source_func = (
+                    mtls.default_client_cert_source() if is_mtls else None
                 )
-                client_options.api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT
-                    if has_client_cert_source
-                    else self.DEFAULT_ENDPOINT
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        else:
+            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+            if use_mtls_env == "never":
+                api_endpoint = self.DEFAULT_ENDPOINT
+            elif use_mtls_env == "always":
+                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+            elif use_mtls_env == "auto":
+                api_endpoint = (
+                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
                 )
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -236,11 +356,11 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
             self._transport = Transport(
                 credentials=credentials,
                 credentials_file=client_options.credentials_file,
-                host=client_options.api_endpoint,
+                host=api_endpoint,
                 scopes=client_options.scopes,
-                api_mtls_endpoint=client_options.api_endpoint,
-                client_cert_source=client_options.client_cert_source,
+                client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
+                client_info=client_info,
             )
 
     def list_jobs(
@@ -255,13 +375,14 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         r"""Lists jobs.
 
         Args:
-            request (:class:`~.cloudscheduler.ListJobsRequest`):
+            request (google.cloud.scheduler_v1.types.ListJobsRequest):
                 The request object. Request message for listing jobs
                 using
                 [ListJobs][google.cloud.scheduler.v1.CloudScheduler.ListJobs].
-            parent (:class:`str`):
+            parent (str):
                 Required. The location name. For example:
                 ``projects/PROJECT_ID/locations/LOCATION_ID``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -273,7 +394,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListJobsPager:
+            google.cloud.scheduler_v1.services.cloud_scheduler.pagers.ListJobsPager:
                 Response message for listing jobs using
                 [ListJobs][google.cloud.scheduler.v1.CloudScheduler.ListJobs].
 
@@ -338,12 +459,13 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         r"""Gets a job.
 
         Args:
-            request (:class:`~.cloudscheduler.GetJobRequest`):
+            request (google.cloud.scheduler_v1.types.GetJobRequest):
                 The request object. Request message for
                 [GetJob][google.cloud.scheduler.v1.CloudScheduler.GetJob].
-            name (:class:`str`):
+            name (str):
                 Required. The job name. For example:
                 ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -355,7 +477,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.job.Job:
+            google.cloud.scheduler_v1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
                 100KB.
@@ -413,16 +535,17 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         r"""Creates a job.
 
         Args:
-            request (:class:`~.cloudscheduler.CreateJobRequest`):
+            request (google.cloud.scheduler_v1.types.CreateJobRequest):
                 The request object. Request message for
                 [CreateJob][google.cloud.scheduler.v1.CloudScheduler.CreateJob].
-            parent (:class:`str`):
+            parent (str):
                 Required. The location name. For example:
                 ``projects/PROJECT_ID/locations/LOCATION_ID``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            job (:class:`~.gcs_job.Job`):
+            job (google.cloud.scheduler_v1.types.Job):
                 Required. The job to add. The user can optionally
                 specify a name for the job in
                 [name][google.cloud.scheduler.v1.Job.name].
@@ -431,6 +554,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 the system will generate a random unique name that will
                 be returned ([name][google.cloud.scheduler.v1.Job.name])
                 in the response.
+
                 This corresponds to the ``job`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -442,7 +566,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.gcs_job.Job:
+            google.cloud.scheduler_v1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
                 100KB.
@@ -513,10 +637,10 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         received.
 
         Args:
-            request (:class:`~.cloudscheduler.UpdateJobRequest`):
+            request (google.cloud.scheduler_v1.types.UpdateJobRequest):
                 The request object. Request message for
                 [UpdateJob][google.cloud.scheduler.v1.CloudScheduler.UpdateJob].
-            job (:class:`~.gcs_job.Job`):
+            job (google.cloud.scheduler_v1.types.Job):
                 Required. The new job properties.
                 [name][google.cloud.scheduler.v1.Job.name] must be
                 specified.
@@ -524,12 +648,14 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 Output only fields cannot be modified using UpdateJob.
                 Any value specified for an output only field will be
                 ignored.
+
                 This corresponds to the ``job`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            update_mask (:class:`~.field_mask.FieldMask`):
+            update_mask (google.protobuf.field_mask_pb2.FieldMask):
                 A  mask used to specify which fields
                 of the job are being updated.
+
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -541,7 +667,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.gcs_job.Job:
+            google.cloud.scheduler_v1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
                 100KB.
@@ -600,13 +726,14 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         r"""Deletes a job.
 
         Args:
-            request (:class:`~.cloudscheduler.DeleteJobRequest`):
+            request (google.cloud.scheduler_v1.types.DeleteJobRequest):
                 The request object. Request message for deleting a job
                 using
                 [DeleteJob][google.cloud.scheduler.v1.CloudScheduler.DeleteJob].
-            name (:class:`str`):
+            name (str):
                 Required. The job name. For example:
                 ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -678,12 +805,13 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         to be paused.
 
         Args:
-            request (:class:`~.cloudscheduler.PauseJobRequest`):
+            request (google.cloud.scheduler_v1.types.PauseJobRequest):
                 The request object. Request message for
                 [PauseJob][google.cloud.scheduler.v1.CloudScheduler.PauseJob].
-            name (:class:`str`):
+            name (str):
                 Required. The job name. For example:
                 ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -695,7 +823,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.job.Job:
+            google.cloud.scheduler_v1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
                 100KB.
@@ -762,12 +890,13 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         to be resumed.
 
         Args:
-            request (:class:`~.cloudscheduler.ResumeJobRequest`):
+            request (google.cloud.scheduler_v1.types.ResumeJobRequest):
                 The request object. Request message for
                 [ResumeJob][google.cloud.scheduler.v1.CloudScheduler.ResumeJob].
-            name (:class:`str`):
+            name (str):
                 Required. The job name. For example:
                 ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -779,7 +908,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.job.Job:
+            google.cloud.scheduler_v1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
                 100KB.
@@ -838,13 +967,14 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
         dispatch the job, even if the job is already running.
 
         Args:
-            request (:class:`~.cloudscheduler.RunJobRequest`):
+            request (google.cloud.scheduler_v1.types.RunJobRequest):
                 The request object. Request message for forcing a job to
                 run now using
                 [RunJob][google.cloud.scheduler.v1.CloudScheduler.RunJob].
-            name (:class:`str`):
+            name (str):
                 Required. The job name. For example:
                 ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -856,7 +986,7 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.job.Job:
+            google.cloud.scheduler_v1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
                 100KB.
@@ -903,11 +1033,11 @@ class CloudSchedulerClient(metaclass=CloudSchedulerClientMeta):
 
 
 try:
-    _client_info = gapic_v1.client_info.ClientInfo(
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution("google-cloud-scheduler",).version,
     )
 except pkg_resources.DistributionNotFound:
-    _client_info = gapic_v1.client_info.ClientInfo()
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
 
 __all__ = ("CloudSchedulerClient",)
