@@ -38,7 +38,7 @@ from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
 from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
 from google.rpc import status_pb2 as status  # type: ignore
 
-from .transports.base import CloudSchedulerTransport
+from .transports.base import CloudSchedulerTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import CloudSchedulerGrpcAsyncIOTransport
 from .client import CloudSchedulerClient
 
@@ -54,10 +54,80 @@ class CloudSchedulerAsyncClient:
     DEFAULT_MTLS_ENDPOINT = CloudSchedulerClient.DEFAULT_MTLS_ENDPOINT
 
     job_path = staticmethod(CloudSchedulerClient.job_path)
+    parse_job_path = staticmethod(CloudSchedulerClient.parse_job_path)
+    topic_path = staticmethod(CloudSchedulerClient.topic_path)
+    parse_topic_path = staticmethod(CloudSchedulerClient.parse_topic_path)
+
+    common_billing_account_path = staticmethod(
+        CloudSchedulerClient.common_billing_account_path
+    )
+    parse_common_billing_account_path = staticmethod(
+        CloudSchedulerClient.parse_common_billing_account_path
+    )
+
+    common_folder_path = staticmethod(CloudSchedulerClient.common_folder_path)
+    parse_common_folder_path = staticmethod(
+        CloudSchedulerClient.parse_common_folder_path
+    )
+
+    common_organization_path = staticmethod(
+        CloudSchedulerClient.common_organization_path
+    )
+    parse_common_organization_path = staticmethod(
+        CloudSchedulerClient.parse_common_organization_path
+    )
+
+    common_project_path = staticmethod(CloudSchedulerClient.common_project_path)
+    parse_common_project_path = staticmethod(
+        CloudSchedulerClient.parse_common_project_path
+    )
+
+    common_location_path = staticmethod(CloudSchedulerClient.common_location_path)
+    parse_common_location_path = staticmethod(
+        CloudSchedulerClient.parse_common_location_path
+    )
+
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            CloudSchedulerAsyncClient: The constructed client.
+        """
+        return CloudSchedulerClient.from_service_account_info.__func__(CloudSchedulerAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+        file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            CloudSchedulerAsyncClient: The constructed client.
+        """
+        return CloudSchedulerClient.from_service_account_file.__func__(CloudSchedulerAsyncClient, filename, *args, **kwargs)  # type: ignore
 
-    from_service_account_file = CloudSchedulerClient.from_service_account_file
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> CloudSchedulerTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            CloudSchedulerTransport: The transport used by the client instance.
+        """
+        return self._client.transport
+
     get_transport_class = functools.partial(
         type(CloudSchedulerClient).get_transport_class, type(CloudSchedulerClient)
     )
@@ -68,6 +138,7 @@ class CloudSchedulerAsyncClient:
         credentials: credentials.Credentials = None,
         transport: Union[str, CloudSchedulerTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
+        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiate the cloud scheduler client.
 
@@ -83,16 +154,19 @@ class CloudSchedulerAsyncClient:
             client_options (ClientOptions): Custom options for the client. It
                 won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
-                default endpoint provided by the client. GOOGLE_API_USE_MTLS
+                default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                 environment variable can also be used to override the endpoint:
                 "always" (always use the default mTLS endpoint), "never" (always
-                use the default regular endpoint, this is the default value for
-                the environment variable) and "auto" (auto switch to the default
-                mTLS endpoint if client SSL credentials is present). However,
-                the ``api_endpoint`` property takes precedence if provided.
-                (2) The ``client_cert_source`` property is used to provide client
-                SSL credentials for mutual TLS transport. If not provided, the
-                default SSL credentials will be used if present.
+                use the default regular endpoint) and "auto" (auto switch to the
+                default mTLS endpoint if client certificate is present, this is
+                the default value). However, the ``api_endpoint`` property takes
+                precedence if provided.
+                (2) If GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
+                is "true", then the ``client_cert_source`` property can be used
+                to provide client certificate for mutual TLS transport. If
+                not provided, the default SSL client certificate will be used if
+                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
+                set, no client certificate will be used.
 
         Raises:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
@@ -100,7 +174,10 @@ class CloudSchedulerAsyncClient:
         """
 
         self._client = CloudSchedulerClient(
-            credentials=credentials, transport=transport, client_options=client_options,
+            credentials=credentials,
+            transport=transport,
+            client_options=client_options,
+            client_info=client_info,
         )
 
     async def list_jobs(
@@ -115,13 +192,14 @@ class CloudSchedulerAsyncClient:
         r"""Lists jobs.
 
         Args:
-            request (:class:`~.cloudscheduler.ListJobsRequest`):
+            request (:class:`google.cloud.scheduler_v1beta1.types.ListJobsRequest`):
                 The request object. Request message for listing jobs
                 using
                 [ListJobs][google.cloud.scheduler.v1beta1.CloudScheduler.ListJobs].
             parent (:class:`str`):
                 Required. The location name. For example:
                 ``projects/PROJECT_ID/locations/LOCATION_ID``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -133,7 +211,7 @@ class CloudSchedulerAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListJobsAsyncPager:
+            google.cloud.scheduler_v1beta1.services.cloud_scheduler.pagers.ListJobsAsyncPager:
                 Response message for listing jobs using
                 [ListJobs][google.cloud.scheduler.v1beta1.CloudScheduler.ListJobs].
 
@@ -144,7 +222,8 @@ class CloudSchedulerAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -167,11 +246,12 @@ class CloudSchedulerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Certain fields should be provided within the metadata header;
@@ -204,12 +284,13 @@ class CloudSchedulerAsyncClient:
         r"""Gets a job.
 
         Args:
-            request (:class:`~.cloudscheduler.GetJobRequest`):
+            request (:class:`google.cloud.scheduler_v1beta1.types.GetJobRequest`):
                 The request object. Request message for
                 [GetJob][google.cloud.scheduler.v1beta1.CloudScheduler.GetJob].
             name (:class:`str`):
                 Required. The job name. For example:
                 ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -221,7 +302,7 @@ class CloudSchedulerAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.job.Job:
+            google.cloud.scheduler_v1beta1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
                 100KB.
@@ -230,7 +311,8 @@ class CloudSchedulerAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -253,11 +335,12 @@ class CloudSchedulerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Certain fields should be provided within the metadata header;
@@ -285,16 +368,17 @@ class CloudSchedulerAsyncClient:
         r"""Creates a job.
 
         Args:
-            request (:class:`~.cloudscheduler.CreateJobRequest`):
+            request (:class:`google.cloud.scheduler_v1beta1.types.CreateJobRequest`):
                 The request object. Request message for
                 [CreateJob][google.cloud.scheduler.v1beta1.CloudScheduler.CreateJob].
             parent (:class:`str`):
                 Required. The location name. For example:
                 ``projects/PROJECT_ID/locations/LOCATION_ID``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            job (:class:`~.gcs_job.Job`):
+            job (:class:`google.cloud.scheduler_v1beta1.types.Job`):
                 Required. The job to add. The user can optionally
                 specify a name for the job in
                 [name][google.cloud.scheduler.v1beta1.Job.name].
@@ -304,6 +388,7 @@ class CloudSchedulerAsyncClient:
                 name that will be returned
                 ([name][google.cloud.scheduler.v1beta1.Job.name]) in the
                 response.
+
                 This corresponds to the ``job`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -315,7 +400,7 @@ class CloudSchedulerAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.gcs_job.Job:
+            google.cloud.scheduler_v1beta1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
                 100KB.
@@ -324,7 +409,8 @@ class CloudSchedulerAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, job]):
+        has_flattened_params = any([parent, job])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -345,7 +431,7 @@ class CloudSchedulerAsyncClient:
         rpc = gapic_v1.method_async.wrap_method(
             self._client._transport.create_job,
             default_timeout=600.0,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Certain fields should be provided within the metadata header;
@@ -384,10 +470,10 @@ class CloudSchedulerAsyncClient:
         received.
 
         Args:
-            request (:class:`~.cloudscheduler.UpdateJobRequest`):
+            request (:class:`google.cloud.scheduler_v1beta1.types.UpdateJobRequest`):
                 The request object. Request message for
                 [UpdateJob][google.cloud.scheduler.v1beta1.CloudScheduler.UpdateJob].
-            job (:class:`~.gcs_job.Job`):
+            job (:class:`google.cloud.scheduler_v1beta1.types.Job`):
                 Required. The new job properties.
                 [name][google.cloud.scheduler.v1beta1.Job.name] must be
                 specified.
@@ -395,12 +481,14 @@ class CloudSchedulerAsyncClient:
                 Output only fields cannot be modified using UpdateJob.
                 Any value specified for an output only field will be
                 ignored.
+
                 This corresponds to the ``job`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            update_mask (:class:`~.field_mask.FieldMask`):
+            update_mask (:class:`google.protobuf.field_mask_pb2.FieldMask`):
                 A  mask used to specify which fields
                 of the job are being updated.
+
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -412,7 +500,7 @@ class CloudSchedulerAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.gcs_job.Job:
+            google.cloud.scheduler_v1beta1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
                 100KB.
@@ -421,7 +509,8 @@ class CloudSchedulerAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([job, update_mask]):
+        has_flattened_params = any([job, update_mask])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -442,7 +531,7 @@ class CloudSchedulerAsyncClient:
         rpc = gapic_v1.method_async.wrap_method(
             self._client._transport.update_job,
             default_timeout=600.0,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Certain fields should be provided within the metadata header;
@@ -469,13 +558,14 @@ class CloudSchedulerAsyncClient:
         r"""Deletes a job.
 
         Args:
-            request (:class:`~.cloudscheduler.DeleteJobRequest`):
+            request (:class:`google.cloud.scheduler_v1beta1.types.DeleteJobRequest`):
                 The request object. Request message for deleting a job
                 using
                 [DeleteJob][google.cloud.scheduler.v1beta1.CloudScheduler.DeleteJob].
             name (:class:`str`):
                 Required. The job name. For example:
                 ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -489,7 +579,8 @@ class CloudSchedulerAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -512,11 +603,12 @@ class CloudSchedulerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Certain fields should be provided within the metadata header;
@@ -553,12 +645,13 @@ class CloudSchedulerAsyncClient:
         to be paused.
 
         Args:
-            request (:class:`~.cloudscheduler.PauseJobRequest`):
+            request (:class:`google.cloud.scheduler_v1beta1.types.PauseJobRequest`):
                 The request object. Request message for
                 [PauseJob][google.cloud.scheduler.v1beta1.CloudScheduler.PauseJob].
             name (:class:`str`):
                 Required. The job name. For example:
                 ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -570,7 +663,7 @@ class CloudSchedulerAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.job.Job:
+            google.cloud.scheduler_v1beta1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
                 100KB.
@@ -579,7 +672,8 @@ class CloudSchedulerAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -602,11 +696,12 @@ class CloudSchedulerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Certain fields should be provided within the metadata header;
@@ -643,12 +738,13 @@ class CloudSchedulerAsyncClient:
         to be resumed.
 
         Args:
-            request (:class:`~.cloudscheduler.ResumeJobRequest`):
+            request (:class:`google.cloud.scheduler_v1beta1.types.ResumeJobRequest`):
                 The request object. Request message for
                 [ResumeJob][google.cloud.scheduler.v1beta1.CloudScheduler.ResumeJob].
             name (:class:`str`):
                 Required. The job name. For example:
                 ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -660,7 +756,7 @@ class CloudSchedulerAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.job.Job:
+            google.cloud.scheduler_v1beta1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
                 100KB.
@@ -669,7 +765,8 @@ class CloudSchedulerAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -692,11 +789,12 @@ class CloudSchedulerAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.ServiceUnavailable, exceptions.DeadlineExceeded,
+                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                 ),
+                deadline=600.0,
             ),
             default_timeout=600.0,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Certain fields should be provided within the metadata header;
@@ -725,13 +823,14 @@ class CloudSchedulerAsyncClient:
         dispatch the job, even if the job is already running.
 
         Args:
-            request (:class:`~.cloudscheduler.RunJobRequest`):
+            request (:class:`google.cloud.scheduler_v1beta1.types.RunJobRequest`):
                 The request object. Request message for forcing a job to
                 run now using
                 [RunJob][google.cloud.scheduler.v1beta1.CloudScheduler.RunJob].
             name (:class:`str`):
                 Required. The job name. For example:
                 ``projects/PROJECT_ID/locations/LOCATION_ID/jobs/JOB_ID``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -743,7 +842,7 @@ class CloudSchedulerAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.job.Job:
+            google.cloud.scheduler_v1beta1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
                 100KB.
@@ -752,7 +851,8 @@ class CloudSchedulerAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -771,7 +871,7 @@ class CloudSchedulerAsyncClient:
         rpc = gapic_v1.method_async.wrap_method(
             self._client._transport.run_job,
             default_timeout=600.0,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Certain fields should be provided within the metadata header;
@@ -788,11 +888,11 @@ class CloudSchedulerAsyncClient:
 
 
 try:
-    _client_info = gapic_v1.client_info.ClientInfo(
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution("google-cloud-scheduler",).version,
     )
 except pkg_resources.DistributionNotFound:
-    _client_info = gapic_v1.client_info.ClientInfo()
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
 
 __all__ = ("CloudSchedulerAsyncClient",)
